@@ -35,7 +35,10 @@ def locale_dir(*args): # i18n files
 def help_dir(*args): # help
     return os.path.join(_help_dir, *args)
 
-def share_dir(*args): # glade + pixmaps
-    return os.path.join(_share_dir, *args)
+def ui_dir(*args):
+    return os.path.join(_share_dir, "glade2", *args)
+
+def icon_dir(*args):
+    return os.path.join(_share_dir, "glade2", "pixmaps", *args)
 
 
