@@ -31,17 +31,21 @@ import os
 import errno
 import _vc
 
-class Vc(_vc.Vc):
+class Vc(_vc.CachedVc):
 
     CMD = "git"
     NAME = "Git"
     VC_DIR = ".git"
     PATCH_STRIP_NUM = 1
     PATCH_INDEX_RE = "^diff --git a/(.*) b/.*$"
-
-    def __init__(self, location):
-        self._tree_cache = None
-        super(Vc, self).__init__(location)
+    state_map = {
+        "unknown":    _vc.STATE_NONE,
+        "new file":   _vc.STATE_NEW,
+        "deleted":    _vc.STATE_REMOVED,
+        "modified":   _vc.STATE_MODIFIED,
+        "typechange": _vc.STATE_MODIFIED,
+        "unmerged":   _vc.STATE_CONFLICT,
+    }
 
     def commit_command(self, message):
         return [self.CMD,"commit","-m",message]
@@ -61,28 +65,15 @@ class Vc(_vc.Vc):
         else:
             return ''
 
-    def cache_inventory(self, topdir):
-        self._tree_cache = self.lookup_tree()
-
-    def uncache_inventory(self):
-        self._tree_cache = None
-
-    def lookup_tree(self):
+    def _lookup_tree_cache(self, rootdir):
         while 1:
             try:
-                proc = os.popen("cd %s && %s status --untracked-files" % (self.root, self.CMD))
+                proc = _vc.popen([self.CMD, "status", "--untracked-files"], cwd=self.root)
                 entries = proc.read().split("\n")[:-1]
                 break
             except OSError, e:
                 if e.errno != errno.EAGAIN:
                     raise
-        statemap = {
-            "unknown": _vc.STATE_NONE,
-            "new file": _vc.STATE_NEW,
-            "deleted": _vc.STATE_REMOVED,
-            "modified": _vc.STATE_MODIFIED,
-            "typechange": _vc.STATE_NORMAL,
-            "unmerged": _vc.STATE_CONFLICT }
         tree_state = {}
         for entry in entries:
             if not entry.startswith("#\t"):
@@ -101,7 +92,7 @@ class Vc(_vc.Vc):
                     src, dst = name.split(" -> ", 2)
                 except ValueError:
                     path = os.path.join(self.root, name.strip())
-                    state = statemap.get(statekey, _vc.STATE_NONE)
+                    state = self.state_map.get(statekey, _vc.STATE_NONE)
                     tree_state[path] = state
                 else:
                     # copied, renamed
@@ -110,15 +101,9 @@ class Vc(_vc.Vc):
                     tree_state[os.path.join(self.root, dst)] = _vc.STATE_NEW
         return tree_state
 
-    def get_tree(self):
-        if self._tree_cache is None:
-            return self.lookup_tree()
-        else:
-            return self._tree_cache
-
     def _get_dirsandfiles(self, directory, dirs, files):
 
-        tree = self.get_tree()
+        tree = self._get_tree_cache(directory)
 
         retfiles = []
         retdirs = []
